;; Generated package description from company.el  -*- no-byte-compile: t -*-
(define-package "company" "0.9.13.0.20230926.3256" "Modular text completion framework" '((emacs "25.1")) :commit "f3ee625daadbff704b620a25c7cdd216a28f2eb5" :maintainer '("Dmitry Gutov" . "dgutov@yandex.ru") :keywords '("abbrev" "convenience" "matching") :url "http://company-mode.github.io/")
